SUBROUTINE GPTET(KPROMA,KSTART,KPROF,KFLEV,PRESF,PT,PKAP,PTETA)

!**** *GPTET* - COMPUTES POTENTIAL TEMPERATURE

!     PURPOSE.
!     --------
!           COMPUTES POTENTIAL TEMPERATURE

!**   INTERFACE.
!     ----------
!        *CALL* *GPTET(KPROMA,KSTART,KPROF,KFLEV,PRESF,PT,PKAP,PTETA)*

!        EXPLICIT ARGUMENTS :
!        --------------------

!         KPROMA                - HORIZONTAL DIMENSIONS          (INPUT)
!         KSTART to KPROF       - DEPTH OF WORK                  (INPUT)
!         KFLEV                 - NUMBER OF MODEL LEVELS         (INPUT)
!         PRESF(KPROMA,KFLEV)   - FULL LEVEL PRESSURE            (INPUT)
!         PT(KPROMA,KFLEV)      - FULL LEVEL TEMPERATURE         (INPUT)
!         PKAP(KPROMA,KFLEV)    - FULL LEVEL KAPPA (GPRCP)       (INPUT)

!         PTETA(KPROMA,KFLEV)   - POTENTIAL TEMPERATURE          (OUTPUT)

!        IMPLICIT ARGUMENTS : CONSTANTS FROM YOMCST.
!        --------------------

!     METHOD.
!     -------
!        SEE DOCUMENTATION

!     EXTERNALS.
!     ----------
!        None.
!        Called by CPG.

!     REFERENCE.
!     ----------
!        ECMWF Research Department documentation of the IFS

!     AUTHOR.
!     -------
!        MATS HAMRUD AND PHILIPPE COURTIER  *ECMWF*

!     MODIFICATIONS.
!     --------------
!        ORIGINAL : 88-02-04
!        K. YESSAD (METEO-FRANCE CNRM/GMAP) 03/03/1992.
!        01-Oct-2003 M. Hamrud   CY28 Cleaning.
!        02-Jan-2006 J. Masek    Adapted for use with flux.
!     ------------------------------------------------------------------

USE MOD_AUX, ONLY : RATM

IMPLICIT NONE

INTEGER,INTENT(IN)    :: KPROMA 
INTEGER,INTENT(IN)    :: KFLEV 
INTEGER,INTENT(IN)    :: KSTART 
INTEGER,INTENT(IN)    :: KPROF 
REAL   ,INTENT(IN)    :: PRESF(KPROMA,KFLEV) 
REAL   ,INTENT(IN)    :: PT(KPROMA,KFLEV) 
REAL   ,INTENT(IN)    :: PKAP(KPROMA,KFLEV) 
REAL   ,INTENT(OUT)   :: PTETA(KPROMA,KFLEV) 
!     INPUT:
!     OUTPUT
INTEGER :: JLEV, JROF

REAL :: ZUSRATM

!     ------------------------------------------------------------------

!*       1.    COMPUTES POTENTIAL TEMPERATURE.
!              -------------------------------

ZUSRATM=1.0/RATM
DO JLEV=1,KFLEV
  DO JROF=KSTART,KPROF
    PTETA(JROF,JLEV)=&
     & +PT(JROF,JLEV)*(PRESF(JROF,JLEV)*ZUSRATM)**(-PKAP(JROF,JLEV))  
  ENDDO
ENDDO

!     ------------------------------------------------------------------

END SUBROUTINE GPTET
