subroutine setup_aux(&
  & kulout  ,&! (I) - logical unit for output messages
  & kdgl    ,&! (I) - number of latitude rows
  & kflevg  ,&! (I) - number of full levels
  & ksefre  ,&! (I) - number of degrees of freedom in spectral space
  & knsmax  ,&! (I) - truncation in latitude
  & ply     ,&! (I) - length of domain in y direction
  & pdely   ,&! (I) - grid size in y direction
  & ldnhdyn  &! (I) - switch for NH dynamics
&)

! -----
! PURPOSE:
!   Initialization of auxiliary constants and global variables.
!
! ORIGINAL:
!   16-08-2002, J. Masek
!
! MODIFICATIONS:
!   02-01-2006, J. Masek
!     All modules merged into mod_aux.
!
! -----

use mod_aux, only: edely, ely,  &
  &  laprxpk, lnhdyn, lrubc, lvercor,  &
  &  ndgl, ndlnpr, nflevg, nsefre, nsmax, nulout,  &
  &  ratm, rcpd, rcpv, rcs, rcvd, rcw, rd, rg, rhydr0, rpi, rv,  &
  &  toppres,  &
  &  yg, yi, yl, ys, yr

implicit none

! -----
! I/O arguments
! -----

integer, intent(in) :: kulout, kdgl, kflevg, ksefre, knsmax

real, intent(in) :: ply, pdely

logical, intent(in) :: ldnhdyn

! =====

! -----
! variables originating from yemgeo
! -----

ely   = ply    ! length of domain in y direction
edely = pdely  ! grid size in y direction

! -----
! variables originating from yomcst
! -----

rpi  = 2.0*asin(1.0)  ! Ludolf number

rg   = 9.80665        ! gravity acceleration                       [m/s**2]

ratm = 100000.        ! reference pressure for defining theta      [Pa]

rd   = 287.060        ! gas constant of dry air                    [J/kg/K]
rcpd = 3.5*rd         ! specific heat of dry air at constant p     [J/kg/K]
rcvd = rcpd - rd      ! specific heat of dry air at constant V     [J/kg/K]

rv   = 461.525        ! gas constant of water vapor                [J/kg/K]
rcpv = 4*rv           ! specific heat of water vapor at constant p [J/kg/K]

rcw  = 4218.          ! specific heat of liquid water              [J/kg/K]

rcs  = 2106.          ! specific heat of ice                       [J/kg/K]

! -----
! variables originating from yomct0
! -----

laprxpk = .FALSE.  ! use exact formula for full level pressure
lrubc   = .FALSE.  ! deactivate RUBC
lvercor = .FALSE.  ! apply thin layer hypothesis

! -----
! variables originating from yomdim
! -----

! dimensions
ndgl   = kdgl    ! number of latitude rows
nflevg = kflevg  ! number of full levels
nsefre = ksefre  ! number of degrees of freedom in spectral space
nsmax  = knsmax  ! truncation in latitude

! -----
! variables originating from yomdyn
! -----

! switch for NH dynamics
lnhdyn = ldnhdyn

if ( ldnhdyn ) then
  ndlnpr = 1  ! use NH formula for d(pi)/pi
else
  ndlnpr = 0  ! use hydrostatic formula for d(pi)/pi
endif
rhydr0 = 1.0  ! upper boundary contition for hydrostatic

! -----
! variables originating from yomgem
! -----

toppres = 0.1  ! top pressure for some vertical calculations [Pa]

! -----
! variables originating from yomlun
! -----

nulout = kulout  ! logical unit number for output messages

! -----
! variables originating from yom_ygfl
! -----

yg%lactive = .FALSE.  ! graupel
yi%lactive = .FALSE.  ! ice
yl%lactive = .FALSE.  ! liquid water
yr%lactive = .FALSE.  ! rain
ys%lactive = .FALSE.  ! snow

! -----

return
end subroutine setup_aux

