subroutine write_2d(&
  & kulgmt ,&! (I) - logical unit number for writing GMT file
  & cdpref ,&! (I) - prefix of GMT file
  & cdbase ,&! (I) - basename of GMT file
  & cdsuff ,&! (I) - suffix of GMT file
  & cdform ,&! (I) - format string
  & p2d    ,&! (I) - 2D array with field to be written
  & px     ,&! (I) - 1D array with x coordinates of points
  & pz     ,&! (I) - 2D array with z coordinates of points
  & kx     ,&! (I) - number of points in horizontal direction
  & kz      &! (I) - number of points in vertical direction
&)

! -----
! PURPOSE:
!   Write 2D field into ascii file (use GMT format).
!
! ORIGINAL:
!   08-08-2002, J. Masek
!
! MODIFIED:
!
! -----

use yomlun, only: nulout

implicit none

! -----
! functions
! -----

integer :: lnblnk

! -----
! subroutine argumnents
! -----

integer, intent(in) :: kulgmt, kx, kz

real, intent(in) :: p2d(kx, kz), px(kx), pz(kx, kz)

character(len = *), intent(in) :: cdpref, cdbase, cdsuff, cdform

! -----
! local variables
! -----

integer :: iret
integer :: jx, jz

character(len = 120) :: clfile

! =====

! join prefix, base and suffix into filename
clfile = cdpref(1:lnblnk(cdpref)) // cdbase(1:lnblnk(cdbase)) //  &
  &  cdsuff(1:lnblnk(cdsuff))

! open output file
open(kulgmt, file = clfile, iostat = iret)
if ( iret /= 0 ) then

  write(nulout, '(a)') 'write_2d: Error:'
  write(nulout, '(3a)')  &
    &  '  Cannot open file ', clfile(1:lnblnk(clfile)), '!'
  call exit(1)

endif

! loop through levels
do jz = 1, kz

  ! loop through gridpoints
  do jx = 1, kx

    ! write triplet (x, z, value)
    write(kulgmt, cdform) px(jx), pz(jx, jz), p2d(jx, jz)

  enddo
enddo

! close output file
close(kulgmt)

return
end subroutine write_2d

